boofun.analysis.decision\_trees
===============================

.. automodule:: boofun.analysis.decision_trees


   .. rubric:: Functions

   .. autosummary::

      compute_randomized_complexity
      count_decision_trees
      decision_tree_depth_dp
      decision_tree_depth_uniform_dp
      decision_tree_depth_weighted_dp
      decision_tree_size_dp
      enumerate_decision_trees
      randomized_complexity_matrix
      reconstruct_tree
      tree_depth
      tree_size

   .. rubric:: Classes

   .. autosummary::

      DecisionTree
